@@ -1,7 +1,8 @@
-from tqdm import tqdm
 import math
 import random
 
+from tqdm import tqdm
+
 def metropolis_acceptance(cost, new_cost, temperature):
 	if new_cost < cost:
 		return 1
@@ -32,7 +33,7 @@ Simulated Annealing Scheme
 """
 def sa(	random_start,
 		objective_function,
-		random_movements,
+		neighbours,
 		acceptance = metropolis_acceptance,
 		T_start = 5,
 		T_stop = 0.05,
@@ -46,7 +47,7 @@ def sa(	random_start,
 	Arguments:
 		random_start: function which returns a random start / state
 		objective_function: objective function to minimize
-		random_movements: **list** of neighbor functions, for one use [func]
+		neighbours: **list** of neighbor functions, for one use [neigh]
 		t_start: Starting temperature
 		T_stop: Stopping temperature
 		alpha: lower temperature by this factor, after repeats proposals
@@ -62,7 +63,7 @@ def sa(	random_start,
 	"""
 	state = random_start()
 	cost = objective_function(state)
-	states, costs = [state], [cost]
+
 	best_found = copy_state(state)
 	best_found_cost = cost
 
@@ -73,18 +74,20 @@ def sa(	random_start,
 	coolings = int( math.ceil(  math.log(T_stop / T) / math.log(alpha)  ) )
 	
 	pbar = tqdm( range(coolings), unit='cooling' )
+	
 	for cooling in pbar:
+
 		T = T * alpha
-		
 		movements_ratio = movements / repeats
-		#print("{} - {}".format(cost, T))
-		pbar.set_description("T: {:5.3f}, M: {:5.2f}, C_min: {:7.4f}, C_current: {:7.4f}".format(T,movements_ratio,best_found_cost,cost))
+		
+		pbar.set_description("T: {:5.3f}, M: {:4.2f}, C_min: {:7.4f}, C_current: {:7.4f}".format(T,movements_ratio,best_found_cost,cost))
 		
 		movements=0
+
 		for _ in range(repeats):
 			
-			random_neighbour = random.choice( random_movements )
-			#print(random_neighbour)
+			random_neighbour = random.choice( neighbours )
+
 			new_state = random_neighbour(state)
 			new_cost = objective_function(new_state)
 	
